package MFColorRGBA;
use strict;
use warnings;

use rlib "./";

use MFScalar;
use base qw(MFScalar);

use SFColorRGBA;
our $SField = new SFColorRGBA;

1;
__END__
